import { Type } from 'class-transformer';
import {
  IsNotEmpty,
  IsNumber,
  IsOptional,
  IsString,
  IsUrl,
  MaxLength,
  MinLength,
} from 'class-validator';

export class MobLoginDto {
  @IsNotEmpty()
  loginId: string;

  @IsNotEmpty()
  deviceId: string;
}

export class WebLoginDto {
  @IsNotEmpty()
  loginId: string;
}

export class SigninDto {
  @IsNotEmpty()
  phoneNumber: string;
}
export class OtpDto {
  @IsNotEmpty()
  phoneNumber: string;

  @IsNotEmpty()
  @Type(() => Number)
  @IsNumber()
  otp: number;
}

export class AdminSigninDto {
  @IsNotEmpty()
  loginId: string;

  @IsOptional()
  password: string;
}

export class UserRegisterDto {
  @IsNotEmpty()
  @MinLength(1)
  @MaxLength(50)
  email: string;

  @IsNotEmpty()
  @MinLength(1)
  @MaxLength(50)
  name: string;

  @IsNotEmpty()
  @MinLength(10)
  @MaxLength(10)
  phoneNumber: string;

  @IsOptional()
  userId: string;
}

export class ForgotPassDto {
  @IsOptional()
  @MinLength(0)
  @MaxLength(50)
  email: string;

  @IsOptional()
  newPassword: string;
}

export class VerifyOtpDto {
  @IsOptional()
  @MinLength(0)
  @MaxLength(50)
  email: string;

  @IsNotEmpty()
  @Type(() => Number)
  otp: string;
}

export class RecruiterRegisterDto {
  @IsNotEmpty()
  name: string;
}
