import { Transform, Type } from 'class-transformer';
import {
    IsBoolean,
  IsNotEmpty,
  IsNumber,
  IsOptional,
  IsString,
  Max,
  MaxLength,
  Min,
  MinLength,
} from 'class-validator';

export class CreateBlogDto {
  @IsNotEmpty()
  @IsString()
  @MinLength(1)
  @MaxLength(100)
  title: string;

  @IsOptional()
  @IsString()
  @MinLength(1)
  @MaxLength(55)
  author: string;

  @IsOptional()
  @IsString()
  @MinLength(0)
  @MaxLength(500)
  desc: string;

  @IsOptional()
  @IsString()
  @MinLength(0)
  @MaxLength(500)
  shortDesc: string;

  @IsOptional()
  date: Date;
}

export class BlogPaginationDto {
  @IsNotEmpty()
  @Transform(({ value }) => value === 'true')
  @IsBoolean()
  popular: number;
}

export class BlogPopularDto {
  @IsNotEmpty()
  @Transform(({ value }) => value === 'true')
  @IsBoolean()
  popular: number;
}
