import { Type } from 'class-transformer';
import {
  IsEnum,
  IsNotEmpty,
  IsNumber,
  IsOptional,
  IsString,
  IsUUID,
  Max,
  MaxLength,
  Min,
  MinLength,
} from 'class-validator';
import { DefaultStatus } from 'src/enum';

export class FaqDto {  
  @IsNotEmpty()
  @IsString()
  @MinLength(1)
  @MaxLength(3000)
  question: string;

  @IsNotEmpty()
  @IsString()
  @MinLength(1)
  @MaxLength(3000)
  answer: string;
}

export class UpdateFaqDto {
  @IsOptional()
  @IsString()
  @MinLength(0)
  @MaxLength(3000)
  question: string;

  @IsOptional()
  @IsString()
  @MinLength(0)
  @MaxLength(3000)
  answer: string;
}

export class FaqPaginationDto {
  @IsNotEmpty()
  @Type(() => Number)
  @IsNumber()
  @Min(10)
  @Max(100)
  limit: number;

  @IsNotEmpty()
  @Type(() => Number)
  @IsNumber()
  @Min(0)
  offset: number;

  @IsOptional()
  @IsString()
  @MinLength(0)
  @MaxLength(100)
  keyword: string;

  @IsNotEmpty()
  @IsEnum(DefaultStatus)
  status: DefaultStatus;

  @IsOptional()
  jobId: string;
}
