import {
  Body,
  Controller,
  Delete,
  Get,
  Param,
  Patch,
  Post,
  Put,
  Query,
  UseGuards,
} from '@nestjs/common';
import { AuthGuard } from '@nestjs/passport';
import { Roles } from 'src/auth/decorators/roles.decorator';
import { RolesGuard } from 'src/auth/guards/roles.guard';
import { CommonPaginationDto } from 'src/common/dto/common-pagination.dto';
import { DefaultStatusDto } from 'src/common/dto/default-status.dto';
import { PermissionAction, UserRole } from 'src/enum';
import { FaqDto, FaqPaginationDto, UpdateFaqDto } from './dto/faq.dto';
import { FaqsService } from './faqs.service';
import { CheckPermissions } from 'src/auth/decorators/permissions.decorator';

@Controller('faqs')
export class FaqsController {
  constructor(private readonly faqsService: FaqsService) {}

  @Post()
  @UseGuards(AuthGuard('jwt'), RolesGuard)
  @Roles(...Object.values(UserRole))
  // @CheckPermissions([PermissionAction.CREATE, 'faq'])
  create(@Body() dto: FaqDto) {
    return this.faqsService.create(dto);
  }

  @Get('list')
  find(@Query() dto: CommonPaginationDto) {
    return this.faqsService.find(dto);
  }

  @Patch('update/:id')
  @UseGuards(AuthGuard('jwt'), RolesGuard)
  @Roles(...Object.values(UserRole))
  // @CheckPermissions([PermissionAction.UPDATE, 'faq'])
  update(@Param('id') id: string, @Body() dto: UpdateFaqDto) {
    return this.faqsService.update(id, dto);
  }

  @Delete('remove/:id')
  @UseGuards(AuthGuard('jwt'), RolesGuard)
  @Roles(...Object.values(UserRole))
  delete(@Param('id') id: string) {
    return this.faqsService.delete(id);
  }
}
