import { Category } from 'src/category/entities/category.entity';
import { DefaultStatus, PosterType } from 'src/enum';
import { SpecialDay } from 'src/special-day/entities/special-day.entity';
import {
  Column,
  CreateDateColumn,
  Entity,
  ManyToOne,
  PrimaryGeneratedColumn,
  UpdateDateColumn,
} from 'typeorm';

@Entity()
export class Poster {
  @PrimaryGeneratedColumn('uuid')
  id: string;

  @Column({ type: 'uuid', nullable: true })
  categoryId: string;

  @Column({ type: 'uuid', nullable: true })
  specialDayId: string;

  @Column({ type: 'text', nullable: true })
  poster: string;

  @Column({ type: 'text', nullable: true })
  posterPath: string;

  @Column({ type: 'varchar', length: 100, nullable: true })
  date: string;

  @Column({ type: 'enum', enum: PosterType, default: PosterType.NEW })
  type: PosterType;

  @Column({ type: 'enum', enum: DefaultStatus, default: DefaultStatus.PENDING })
  status: DefaultStatus;

  @Column({ type: 'int', default: 0 })
  downloadCount: number;

  @CreateDateColumn()
  createdAt: Date;

  @UpdateDateColumn()
  updatedAt: Date;

  @ManyToOne(() => Category, (category) => category.poster, {
    cascade: true,
    onDelete: 'CASCADE',
    onUpdate: 'CASCADE',
  })
  category: Category[];

  @ManyToOne(() => SpecialDay, (specialDay) => specialDay.poster, {
    cascade: true,
    onDelete: 'CASCADE',
    onUpdate: 'CASCADE',
  })
  specialDay: SpecialDay[];
}
