import {
  Injectable,
  NotFoundException,
} from '@nestjs/common';
import {
  CreateSpecialDayDto,
  SpecialDayPaginationDto,
} from './dto/create-special-day.dto';
import { UpdateSpecialDayDto } from './dto/update-special-day.dto';
import { InjectRepository } from '@nestjs/typeorm';
import { SpecialDay } from './entities/special-day.entity';
import { Brackets, Repository } from 'typeorm';
import { DefaultStatus } from 'src/enum';
import { DefaultStatusDto } from 'src/common/dto/default-status.dto';

@Injectable()
export class SpecialDayService {
  constructor(
    @InjectRepository(SpecialDay) private readonly repo: Repository<SpecialDay>,
  ) {}

  async create(dto: CreateSpecialDayDto) {
    const obj = Object.assign(dto);
    return this.repo.save(obj);
  }

  async findAll(dto: SpecialDayPaginationDto) {
    const keyword = dto.keyword || '';
    const query = await this.repo
      .createQueryBuilder('specialDay')
      .where('specialDay.status = :status', {
        status: dto.status,
      });
    if (keyword) {
      query.andWhere(
        new Brackets((qb) => {
          qb.where(
            'specialDay.month LIKE :keyword OR specialDay.name LIKE :keyword',
            {
              keyword: '%' + keyword + '%',
            },
          );
        }),
      );
    }
    const [result, total] = await query
      .take(dto.limit)
      .skip(dto.offset)
      .getManyAndCount();
    return { result, total };
  }

  async findByUser() {
    const [result, total] = await this.repo
      .createQueryBuilder('specialDay')
      .where('specialDay.status = :status', {
        status: DefaultStatus.ACTIVE,
      })
      .getManyAndCount();
    return { result, total };
  }

  async update(id: string, dto: UpdateSpecialDayDto) {
    const result = await this.repo.findOne({ where: { id } });
    if (!result) {
      throw new NotFoundException('Day not found!');
    }
    const obj = Object.assign(result, dto);
    return this.repo.save(obj);
  }

  async status(id: string, dto: DefaultStatusDto) {
    const result = await this.repo.findOne({ where: { id } });
    if (!result) {
      throw new NotFoundException('Day not found!');
    }
    const obj = Object.assign(result, { status: dto.status });
    return this.repo.save(obj);
  }

  // async changeYear(year: string) {
  //   const newYear = parseInt(year, 10);
  //   if (isNaN(newYear) || newYear < 1000 || newYear > 9999) {
  //     throw new Error('Invalid year provided');
  //   }
  //   const specialDays = await this.repo.find();

  //   for (const day of specialDays) {
  //     const oldDate = new Date(day.date);
  //     const newDate = new Date(newYear, oldDate.getMonth(), oldDate.getDate());
  //     day.date = newDate;
  //     await this.repo.save(day);
  //   }
  //   return { update: true, message: `Updated` };
  // }
}
