import { Type } from 'class-transformer';
import {
  IsString,
  MinLength,
  MaxLength,
  IsOptional,
  IsNotEmpty,
  IsNumber,
  Max,
  Min,
  IsEnum,
  IsEmail,
} from 'class-validator';

export class UpdateUserDetailDto {
  @IsOptional()
  @IsString()
  @MinLength(0)
  @MaxLength(50)
  name: string;

  @IsOptional()
  @IsEmail()
  @MinLength(0)
  @MaxLength(50)
  email: string;

  @IsOptional()
  fb: string;

  @IsOptional()
  insta: string;

  @IsOptional()
  twitter: string;

  @IsOptional()
  accountId: string;
}

export class UpdateUserDetailByAdminDto {
  @IsOptional()
  @IsString()
  @MinLength(0)
  @MaxLength(50)
  adminAssignName: string;

  @IsOptional()
  @MinLength(0)
  @MaxLength(50)
  designation: string;
}

export class PaginationSDto {
  @IsNotEmpty()
  @Type(() => Number)
  @IsNumber()
  @Min(10)
  @Max(50)
  limit: number;

  @IsNotEmpty()
  @Type(() => Number)
  @IsNumber()
  @Min(0)
  offset: number;

  @IsOptional()
  keyword: string;
}
