import { Injectable, NotFoundException } from '@nestjs/common';
import { InjectRepository } from '@nestjs/typeorm';
import { Account } from 'src/account/entities/account.entity';
import { Brackets, Repository } from 'typeorm';
import { PaginationSDto, UpdateUserDetailByAdminDto, UpdateUserDetailDto } from './dto/update-user-details';
import { UserDetail } from './entities/user-detail.entity';

@Injectable()
export class UserDetailsService {
  constructor(
    @InjectRepository(UserDetail) private readonly repo: Repository<UserDetail>,
    @InjectRepository(Account)
    private readonly accountrepo: Repository<Account>,
  ) {}

  async findOne(id: string) {
    const result = await this.repo.findOne({ where: { accountId: id } });
    if (!result) {
      throw new NotFoundException('User not found!');
    }
    return result;
  }

  async update(dto: UpdateUserDetailDto, accountId: string) {
    const result = await this.repo.findOne({ where: { accountId: accountId } });
    if (!result) {
      throw new NotFoundException('User profile not found!');
    }
    const obj = Object.assign(result, dto);
    return this.repo.save(obj);
  }

  async updateByAdmin(dto: UpdateUserDetailByAdminDto, accountId: string) {   
    const result = await this.repo.findOne({ where: { accountId: accountId } });
    if (!result) {
      throw new NotFoundException('User profile not found!');
    }
    const obj = Object.assign(result, dto);
    return this.repo.save(obj);
  }

  async profileImage(image: string, result: UserDetail) {
    const obj = Object.assign(result, {
      profile: process.env.POLY_UPLOAD_LINK + image,
      profileName: image,
    });
    return this.repo.save(obj);
  }

  async top(image: string, result: UserDetail) {
    const obj = Object.assign(result, {
      top: process.env.POLY_UPLOAD_LINK + image,
      topPath: image,
    });
    return this.repo.save(obj);
  }

  async bottom(image: string, result: UserDetail) {
    const obj = Object.assign(result, {
      bottom: process.env.POLY_UPLOAD_LINK + image,
      bottomPath: image,
    });
    return this.repo.save(obj);
  }
}
